@@ -37,9 +37,9 @@ _maix_vivo_module = Pybind11Extension("_maix_vivo",
 _maix_speech_module = Pybind11Extension("_maix_speech",
     include_dirs=[
         get_incs(
-            'ext_modules/_maix_speech/Maix-Speech/components/asr_lib/include'),
+            './ext_modules/libmaix/components/maix_speech/Maix-Speech/components/asr_lib/include'),
         get_incs(
-            'ext_modules/_maix_speech/Maix-Speech/components/utils/include')
+            './ext_modules/libmaix/components/maix_speech/Maix-Speech/components/utils/include')
     ],
     sources = get_srcs('ext_modules/_maix_speech', exclude=["utils", "projects"]),
     libraries=[
@@ -47,10 +47,10 @@ _maix_speech_module = Pybind11Extension("_maix_speech",
     ],
     library_dirs=[
         ext_so,
-        "./ext_modules/_maix_speech/Maix-Speech/components/asr_lib/lib/v83x",
+        "./ext_modules/libmaix/components/maix_speech/Maix-Speech/components/asr_lib/lib/v83x",
     ],
     extra_objects=[
-        "./ext_modules/_maix_speech/Maix-Speech/components/asr_lib/lib/v83x/libms_asr_v83x.a",
+        "./ext_modules/libmaix/components/maix_speech/Maix-Speech/components/asr_lib/lib/v83x/libms_asr_v83x.a",
     ],
     extra_compile_args=['-D__ARM__', '-D__ARMV7__', '-DCONF_KERNEL_IOMMU', '-DCONF_KERNEL_VERSION_4_9', '-std=c++11', '-std=gnu++11'],
     extra_link_args=[
@@ -139,10 +139,17 @@ _maix_image_module = Pybind11Extension("_maix_image",
             'ext_modules/libmaix/components/libmaix/lib/arch/v83x/include/opencv4/'),
         get_incs(
             'ext_modules/libmaix/components/maix_cv_image/include'),
+        get_incs(
+            'ext_modules/libmaix/components/third_party/include'),
+        get_incs(
+            'ext_modules/libmaix/components/third_party/imlib/include'),
         get_incs(
             'ext_modules/_maix_image/include')
     ],
-    sources = get_srcs('ext_modules/_maix_image') + get_srcs('ext_modules/libmaix/components/maix_cv_image/src'),
+    sources =
+            get_srcs('ext_modules/_maix_image') +
+            get_srcs('ext_modules/libmaix/components/maix_cv_image/src') +
+            get_srcs('ext_modules/libmaix/components/third_party/imlib/src'),
     libraries=[
         "maix_utils", "maix_cam", "maix_disp", "maix_image",
         "opencv_videoio", "opencv_highgui", "opencv_core", "opencv_imgproc", "opencv_imgcodecs", "opencv_freetype"
@@ -164,7 +171,7 @@ _maix_image_module = Pybind11Extension("_maix_image",
         "-Wl,-rpath=/usr/lib/python3.8/site-packages/maix",
         "-Wl,-rpath=/usr/lib/python3.8/site-packages/maix/_maix_opencv"
     ],
-    extra_compile_args=['-std=c++11', '-std=gnu++11' ],
+    extra_compile_args=['-std=c++11', '-std=gnu++11', '-DIMLIB_CONFIG_H_FILE="costom_imlib_config.h"' ],
 )
 
 _maix_modules = [
@@ -185,7 +192,6 @@ _maix_data_files = [
 
 _maix_py_modules = [
     "numpy",
-    "Pillow",
     "rpyc",
     "gpiod",
     "evdev",
