@@ -763,7 +763,7 @@ maix_image &maix_image::_hist_eq(bool adaptive,float clip_limit,maix_image & mas
       imlib_histeq(&img, mask_img);
 	  fb_alloc_free_till_mark();
 
-    if (NULL!=mask._img && this->_img->width == mask._img->width && this->_img->height == mask._img->height ) 
+    if (NULL!=mask._img && this->_img->width == mask._img->width && this->_img->height == mask._img->height )
       free(mask_img), mask_img = NULL;
 
     return * this;
@@ -804,7 +804,7 @@ maix_image &maix_image::_lens_corr(float strength, float zoom, float x_corr, flo
     fb_alloc_mark();
     imlib_lens_corr(&img,strength,zoom,x_corr,y_corr);
     fb_alloc_free_till_mark();
-    
+
     return * this;
 }
 
@@ -846,4 +846,161 @@ maix_image &maix_image::_mean(const int ksize, bool threshold, int offset,bool i
     if (mask_img!=NULL) free(mask_img), mask_img = NULL;
 
     return * this;
-}
\ No newline at end of file
+}
+
+
+
+py::list maix_image::_imlib_get_statistics(std::vector<int> roi_src, std::vector<std::vector<int>> &thresholds_src, bool invert, maix_image & other_src, int bins, int l_bins, int a_bins, int b_bins)
+{
+
+  if (NULL == this->_img)
+  {
+    py::print("no img");
+    return py::none();
+  }
+
+  image_t img_tmp = { }, *arg_img = &img_tmp;
+  arg_img->w = this->_img->width;
+  arg_img->h = this->_img->height;
+  arg_img->pixels = (uint8_t*)this->_img->data;
+  arg_img->pixfmt = PIXFORMAT_RGB888;
+
+  image_t other_img = {}, *other = NULL;
+  if (NULL != other_src._img)
+  {
+      other->w = other_src._img->width;
+      other->h = other_src._img->height;
+      other->pixels = (uint8_t*)other_src._img->data;
+      other->pixfmt = PIXFORMAT_RGB888;
+      other = &other_img;
+  }
+
+  fb_alloc_mark();
+
+  list_t thresholds;
+  list_init(&thresholds, sizeof(color_thresholds_list_lnk_data_t));
+  for (auto src : thresholds_src)
+  {
+    color_thresholds_list_lnk_data_t tmp_ct;
+    tmp_ct.LMin = src[0];
+    tmp_ct.LMax = src[1];
+    tmp_ct.AMin = src[2];
+    tmp_ct.AMax = src[3];
+    tmp_ct.BMin = src[4];
+    tmp_ct.BMax = src[5];
+    list_push_back(&thresholds, &tmp_ct);
+  }
+
+  if (roi_src[2] == 0) roi_src[2] = arg_img->w;
+  if (roi_src[3] == 0) roi_src[3] = arg_img->h;
+
+  rectangle_t roi = { roi_src[0], roi_src[1], roi_src[2], roi_src[3] };
+
+  histogram_t hist;
+
+  switch (arg_img->pixfmt) {
+    case PIXFORMAT_GRAYSCALE: {
+      if (bins >= 2 && bins <= 255) {
+        hist.LBinCount = bins;
+      } else {
+        hist.LBinCount = bins = 255;
+      }
+      if (hist.LBinCount >= 2) {
+        hist.ABinCount = 0;
+        hist.BBinCount = 0;
+        hist.LBins = (float *)fb_alloc(hist.LBinCount * sizeof(float), FB_ALLOC_NO_HINT);
+        hist.ABins = NULL;
+        hist.BBins = NULL;
+        imlib_get_histogram(&hist, arg_img, &roi, &thresholds, invert, other);
+        list_free(&thresholds);
+      }
+      break;
+    }
+    case PIXFORMAT_RGB565:
+    case PIXFORMAT_RGB888: {
+      if (bins >= 2 && bins <= 255) {
+        hist.LBinCount = bins;
+      } else {
+        hist.LBinCount = bins = 255;
+      }
+      if (l_bins < 2) l_bins = bins;
+      hist.LBinCount = l_bins;
+      if (a_bins < 2) a_bins = bins;
+      hist.ABinCount = a_bins;
+      if (b_bins < 2) b_bins = bins;
+      hist.BBinCount = b_bins;
+
+      if (hist.LBinCount >= 2 && hist.ABinCount >= 2 && hist.BBinCount >= 2) {
+        hist.LBins = (float *)fb_alloc(hist.LBinCount * sizeof(float), FB_ALLOC_NO_HINT);
+        hist.ABins = (float *)fb_alloc(hist.ABinCount * sizeof(float), FB_ALLOC_NO_HINT);
+        hist.BBins = (float *)fb_alloc(hist.BBinCount * sizeof(float), FB_ALLOC_NO_HINT);
+        imlib_get_histogram(&hist, arg_img, &roi, &thresholds, invert, other);
+        list_free(&thresholds);
+      }
+      break;
+    }
+  }
+
+  statistics_t stats;
+  imlib_get_statistics(&stats, (pixformat_t)arg_img->pixfmt, &hist);
+
+  py::list tmps;
+
+  tmps.append(stats.LMean);
+  tmps.append(stats.LMedian);
+  tmps.append(stats.LMode);
+  tmps.append(stats.LSTDev);
+  tmps.append(stats.LMin);
+  tmps.append(stats.LMax);
+  tmps.append(stats.LLQ);
+  tmps.append(stats.LUQ);
+
+  tmps.append(stats.AMean);
+  tmps.append(stats.AMedian);
+  tmps.append(stats.AMode);
+  tmps.append(stats.ASTDev);
+  tmps.append(stats.AMin);
+  tmps.append(stats.AMax);
+  tmps.append(stats.ALQ);
+  tmps.append(stats.AUQ);
+
+  tmps.append(stats.BMean);
+  tmps.append(stats.BMedian);
+  tmps.append(stats.BMode);
+  tmps.append(stats.BSTDev);
+  tmps.append(stats.BMin);
+  tmps.append(stats.BMax);
+  tmps.append(stats.BLQ);
+  tmps.append(stats.BUQ);
+
+  fb_alloc_free_till_mark();
+
+  return tmps;
+}
+
+maix_image &maix_image::_imlib_rotation_corr(float x_rotation, float y_rotation, float z_rotation, float x_translation, float y_translation, float zoom, float fov, std::vector<std::vector<float>> corners)
+{
+  if (NULL == this->_img)
+  {
+    py::print("no img");
+    return *this;
+  }
+
+  // image_t *imlib_img = imlib_image_create(img->width, img->height, PIXFORMAT_RGB888, img->width * img->height * PIXFORMAT_BPP_RGB888, img->data, false);
+
+  image_t img_tmp = {}, *img = &img_tmp;
+  img->w = this->_img->width;
+  img->h = this->_img->height;
+  img->pixels = (uint8_t*)this->_img->data;
+  img->pixfmt = PIXFORMAT_RGB888;
+
+  fb_alloc_mark();
+
+  imlib_rotation_corr(img, x_rotation, y_rotation, z_rotation, x_translation, y_translation, zoom, fov, NULL);
+
+  fb_alloc_free_till_mark();
+
+  // imlib_image_destroy(&resize_img);
+
+  return *this;
+}
