@@ -31,5 +31,6 @@ void set_inputs_scale(float * values , ini_info_t * ini_info);
 void set_outputs_scale(float * values , ini_info_t * ini_info);
 int get_section(FILE * fp , char *title , ini_info_t * ini_info);
 ini_info_t read_file (char * mdsc_path);
-libmaix_nn_t* load_mdsc(char * path);
+libmaix_nn_t* load_mdsc(char * path , ini_info_t * info_ptr);
+libmaix_nn_t* build_model(ini_info_t * info_ptr);
 #endif
\ No newline at end of file
