@@ -126,10 +126,12 @@ class libmaix_font
 public:
   static cv::Ptr<cv::freetype::FreeType2> ft;
   static bool is_load;
+  static int fontHeight;
 };
 
 cv::Ptr<cv::freetype::FreeType2> libmaix_font::ft = cv::freetype::createFreeType2();
 bool libmaix_font::is_load = false;
+int libmaix_font::fontHeight = 14;
 
 extern "C"
 {
@@ -161,14 +163,28 @@ extern "C"
     {
       return LIBMAIX_ERR_PARAM;
     }
-    if (src->mode == LIBMAIX_IMAGE_MODE_RGB888)
+    // if (src->mode == LIBMAIX_IMAGE_MODE_RGB888)
+    int type = CV_8UC3;
+    switch (src->mode)
     {
-      cv::Mat input(src->height, src->width, CV_8UC3, const_cast<char *>((char *)src->data));
-      cv::ellipse(input, cv::Point(x, y), cv::Size(w, h), angle, startAngle, endAngle, cv::Scalar(color.rgb888.r, color.rgb888.g, color.rgb888.b), thickness);
+      case LIBMAIX_IMAGE_MODE_RGB888:
+        break;
+      case LIBMAIX_IMAGE_MODE_RGBA8888:
+        type = CV_8UC4;
+        break;
+      case LIBMAIX_IMAGE_MODE_GRAY:
+        type = CV_8UC1;
+        break;
+      default:
+        return LIBMAIX_ERR_NOT_IMPLEMENT;
+    }
+    {
+      cv::Mat input(src->height, src->width, type, const_cast<char *>((char *)src->data));
+      cv::ellipse(input, cv::Point(x, y), cv::Size(w, h), angle, startAngle, endAngle, cv::Scalar(color.rgb888.r, color.rgb888.g, color.rgb888.b, color.rgb888.a), thickness);
       // memcpy(src->data, input.data, src->width * src->height * 3);
       return LIBMAIX_ERR_NONE;
     }
-    return LIBMAIX_ERR_NOT_IMPLEMENT;
+    // return LIBMAIX_ERR_NOT_IMPLEMENT;
   }
 
   libmaix_err_t libmaix_cv_image_draw_circle(libmaix_image_t *src, int x, int y, int r, libmaix_image_color_t color, int thickness)
@@ -177,14 +193,28 @@ extern "C"
     {
       return LIBMAIX_ERR_PARAM;
     }
-    if (src->mode == LIBMAIX_IMAGE_MODE_RGB888)
+    // if (src->mode == LIBMAIX_IMAGE_MODE_RGB888)
+    int type = CV_8UC3;
+    switch (src->mode)
     {
-      cv::Mat input(src->height, src->width, CV_8UC3, src->data);
-      cv::circle(input, cv::Point(x, y), r, cv::Scalar(color.rgb888.r, color.rgb888.g, color.rgb888.b), thickness);
+      case LIBMAIX_IMAGE_MODE_RGB888:
+        break;
+      case LIBMAIX_IMAGE_MODE_RGBA8888:
+        type = CV_8UC4;
+        break;
+      case LIBMAIX_IMAGE_MODE_GRAY:
+        type = CV_8UC1;
+        break;
+      default:
+        return LIBMAIX_ERR_NOT_IMPLEMENT;
+    }
+    {
+      cv::Mat input(src->height, src->width, type, src->data);
+      cv::circle(input, cv::Point(x, y), r, cv::Scalar(color.rgb888.r, color.rgb888.g, color.rgb888.b, color.rgb888.a), thickness);
       // memcpy(src->data, input.data, src->width * src->height * 3);
       return LIBMAIX_ERR_NONE;
     }
-    return LIBMAIX_ERR_NOT_IMPLEMENT;
+    // return LIBMAIX_ERR_NOT_IMPLEMENT;
   }
 
   libmaix_err_t libmaix_cv_image_draw_rectangle(libmaix_image_t *src, int x1, int y1, int x2, int y2, libmaix_image_color_t color, int thickness)
@@ -193,14 +223,28 @@ extern "C"
     {
       return LIBMAIX_ERR_PARAM;
     }
-    if (src->mode == LIBMAIX_IMAGE_MODE_RGB888)
+    // if (src->mode == LIBMAIX_IMAGE_MODE_RGB888)
+    int type = CV_8UC3;
+    switch (src->mode)
     {
-      cv::Mat input(src->height, src->width, CV_8UC3, src->data);
-      cv::rectangle(input, cv::Point(x1, y1), cv::Point(x2, y2), cv::Scalar(color.rgb888.r, color.rgb888.g, color.rgb888.b), thickness);
+      case LIBMAIX_IMAGE_MODE_RGB888:
+        break;
+      case LIBMAIX_IMAGE_MODE_RGBA8888:
+        type = CV_8UC4;
+        break;
+      case LIBMAIX_IMAGE_MODE_GRAY:
+        type = CV_8UC1;
+        break;
+      default:
+        return LIBMAIX_ERR_NOT_IMPLEMENT;
+    }
+    {
+      cv::Mat input(src->height, src->width, type, src->data);
+      cv::rectangle(input, cv::Point(x1, y1), cv::Point(x2, y2), cv::Scalar(color.rgb888.r, color.rgb888.g, color.rgb888.b, color.rgb888.a), thickness);
       // memcpy(src->data, input.data, src->width * src->height * 3);
       return LIBMAIX_ERR_NONE;
     }
-    return LIBMAIX_ERR_NOT_IMPLEMENT;
+    // return LIBMAIX_ERR_NOT_IMPLEMENT;
   }
 
   libmaix_err_t libmaix_cv_image_draw_line(libmaix_image_t *src, int x1, int y1, int x2, int y2, libmaix_image_color_t color, int thickness)
@@ -209,14 +253,28 @@ extern "C"
     {
       return LIBMAIX_ERR_PARAM;
     }
-    if (src->mode == LIBMAIX_IMAGE_MODE_RGB888)
+    int type = CV_8UC3;
+    switch (src->mode)
     {
-      cv::Mat input(src->height, src->width, CV_8UC3, src->data);
-      cv::line(input, cv::Point(x1, y1), cv::Point(x2, y2), cv::Scalar(color.rgb888.r, color.rgb888.g, color.rgb888.b), thickness);
+      case LIBMAIX_IMAGE_MODE_RGB888:
+        break;
+      case LIBMAIX_IMAGE_MODE_RGBA8888:
+        type = CV_8UC4;
+        break;
+      case LIBMAIX_IMAGE_MODE_GRAY:
+        type = CV_8UC1;
+        break;
+      default:
+        return LIBMAIX_ERR_NOT_IMPLEMENT;
+    }
+    // if (src->mode == LIBMAIX_IMAGE_MODE_RGB888)
+    {
+      cv::Mat input(src->height, src->width, type, src->data);
+      cv::line(input, cv::Point(x1, y1), cv::Point(x2, y2), cv::Scalar(color.rgb888.r, color.rgb888.g, color.rgb888.b, color.rgb888.a), thickness);
       // memcpy(src->data, input.data, src->width * src->height * 3);
       return LIBMAIX_ERR_NONE;
     }
-    return LIBMAIX_ERR_NOT_IMPLEMENT;
+    // return LIBMAIX_ERR_NOT_IMPLEMENT;
   }
 
   libmaix_err_t libmaix_cv_image_draw_image(libmaix_image_t *src, int x, int y, libmaix_image_t *dst, double opacity)
@@ -267,7 +325,7 @@ extern "C"
     }
     return LIBMAIX_ERR_NOT_IMPLEMENT;
   }
-  libmaix_err_t libmaix_cv_image_draw_image_save(libmaix_image_t *src, const char *path)
+  libmaix_err_t libmaix_cv_image_save_file(libmaix_image_t *src, const char *path)
   {
     if (src->data == NULL)
     {
@@ -284,37 +342,39 @@ extern "C"
     return LIBMAIX_ERR_NOT_IMPLEMENT;
   }
 
-  libmaix_err_t libmaix_cv_image_load_freetype(const char *path)
+  libmaix_err_t libmaix_cv_image_load_freetype(const char *path, int fontHeight)
   {
     if (libmaix_font::is_load)
       libmaix_font::ft = cv::freetype::createFreeType2(); // re-load clear it
     libmaix_font::ft->loadFontData(cv::String(path), 0);
     libmaix_font::is_load = true;
+    libmaix_font::fontHeight = fontHeight;
     return LIBMAIX_ERR_NONE;
   }
 
-  // libmaix_err_t libmaix_cv_image_font_free()
-  // {
-  //     delete libmaix_font::ft;
-  //     return LIBMAIX_ERR_NONE;
-  // }
+  libmaix_err_t libmaix_cv_image_free_freetype()
+  {
+      if (libmaix_font::is_load)
+        delete libmaix_font::ft;
+        libmaix_font::is_load = false;
+      return LIBMAIX_ERR_NONE;
+  }
 
   void libmaix_cv_image_get_string_size(int *width, int *height, const char *str, double scale, int thickness)
   {
+      int baseline = 0;
       cv::String text(str);
       if (!libmaix_font::is_load)
       {
-        int baseline = 0;
         cv::Size textSize = cv::getTextSize(text, cv::FONT_HERSHEY_PLAIN, scale, thickness, &baseline);
         int tmp = baseline - (scale * thickness);
-        *width = textSize.width, *height = textSize.height + tmp;
+        *width = textSize.width * scale, *height = textSize.height + tmp;
         // printf("old textSize w %d h %d b %d\r\n", textSize.width, textSize.height, baseline);
       }
       else
       {
-        int fontHeight = 14, baseline = 0; // tested sans.ttf
-        cv::Size textSize = libmaix_font::ft->getTextSize(text, fontHeight, thickness, &baseline);
-        *width = textSize.width, *height = fontHeight * scale;
+        cv::Size textSize = libmaix_font::ft->getTextSize(text, libmaix_font::fontHeight, thickness, &baseline);
+        *width = textSize.width * scale, *height = libmaix_font::fontHeight * scale;
         // printf("new textSize w %d h %d b %d\r\n", textSize.width, textSize.height, baseline);
       }
   }
@@ -325,30 +385,39 @@ extern "C"
     {
       return LIBMAIX_ERR_PARAM;
     }
-    if (src->mode == LIBMAIX_IMAGE_MODE_RGB888)
+    int type = CV_8UC3;
+    switch (src->mode)
     {
-      cv::Mat input(src->height, src->width, CV_8UC3, src->data);
-      cv::String text(str);
-      if (!libmaix_font::is_load)
-      {
-        int baseline = 0;
-        cv::Size textSize = cv::getTextSize(text, cv::FONT_HERSHEY_PLAIN, scale, thickness, &baseline);
-        // printf("old textSize w %d h %d b %d\r\n", textSize.width, textSize.height, baseline);
-        int tmp = baseline - (scale * thickness);
-        cv::putText(input, text, cv::Point(x, y + textSize.height + tmp), cv::FONT_HERSHEY_PLAIN, scale,
-            cv::Scalar(color.rgb888.r, color.rgb888.g, color.rgb888.b), thickness);
-      }
-      else
-      {
-        int fontHeight = 14, baseline = 0;
-        cv::Size textSize = libmaix_font::ft->getTextSize(text, fontHeight, thickness, &baseline);
-        // printf("new textSize w %d h %d b %d\r\n", textSize.width, textSize.height, baseline);
-        libmaix_font::ft->putText(input, text, cv::Point(x, y), fontHeight * scale,
-            cv::Scalar(color.rgb888.r, color.rgb888.g, color.rgb888.b), -1, 8, false);
-      }
-      return LIBMAIX_ERR_NOT_READY;
+      case LIBMAIX_IMAGE_MODE_RGB888:
+        break;
+      case LIBMAIX_IMAGE_MODE_RGBA8888:
+        type = CV_8UC4;
+        break;
+      case LIBMAIX_IMAGE_MODE_GRAY:
+        type = CV_8UC1;
+        break;
+      default:
+        return LIBMAIX_ERR_NOT_IMPLEMENT;
     }
-    return LIBMAIX_ERR_NOT_IMPLEMENT;
+    cv::Mat input(src->height, src->width, type, src->data);
+    cv::String text(str);
+    int baseline = 0;
+    if (!libmaix_font::is_load)
+    {
+      cv::Size textSize = cv::getTextSize(text, cv::FONT_HERSHEY_PLAIN, scale, thickness, &baseline);
+      // printf("old textSize w %d h %d b %d\r\n", textSize.width, textSize.height, baseline);
+      int tmp = baseline - (scale * thickness);
+      cv::putText(input, text, cv::Point(x, y + textSize.height + tmp), cv::FONT_HERSHEY_PLAIN, scale,
+          cv::Scalar(color.rgb888.r, color.rgb888.g, color.rgb888.b, color.rgb888.a), thickness);
+    }
+    else
+    {
+      cv::Size textSize = libmaix_font::ft->getTextSize(text, libmaix_font::fontHeight, thickness, &baseline);
+      // printf("new textSize w %d h %d b %d\r\n", textSize.width, textSize.height, baseline);
+      libmaix_font::ft->putText(input, text, cv::Point(x, y), libmaix_font::fontHeight * scale,
+          cv::Scalar(color.rgb888.r, color.rgb888.g, color.rgb888.b, color.rgb888.a), -1, 16, false);
+    }
+    return LIBMAIX_ERR_NONE;
   }
 
   static inline int libmaix_cv_image_load(struct libmaix_image *src, struct libmaix_image **dst)
